salabim
-------
Object oriented discrete event simulation and animation in Python.

Discrete event simulation (DES) can be used in a variety of logistics applications:

* production facilities
* warehousing
* (air)ports
* hospitals
* mining
* materials handling
* steel mills

, but also in other areas, like computer network analysis.

Salabim follows a well proven and very intuitive process description method (like Tomas and Must).
The package provides

* components
* queues
* resources
* stores
* states
* monitors for data collection and presentation
* 2D animation (including video production)
* 3D animation (including video production)
* tracing facilities
* advanced statistical sampling

In contrast to some other Python DES packages it is not required to use yield statements for the process control.
Salabim has very minimal requirements (without animation none). 

Salabim runs under Windows, MacOS, Linux, iOS/iPadOS (Pythonista) and can be used with "Python In Excel".

See www.salabim.org for details. 

See www.salabim.org/manual for the documentation.
